summaryrefslogtreecommitdiffstats
path: root/src/gallium/drivers/iris/iris_batch.c
diff options
context:
space:
mode:
authorKenneth Graunke <[email protected]>2018-07-31 16:10:50 -0700
committerKenneth Graunke <[email protected]>2019-02-21 10:26:08 -0800
commit621cb43f415cb30d2fc3cc020ba30a2a71acfae7 (patch)
treefc4d31b022fb3f6e755c5acf50c1959d373ab8c6 /src/gallium/drivers/iris/iris_batch.c
parent1a9651f29af19e6fb6378f3e061038c8c6672d4e (diff)
iris: rename ring to engine
makes more sense these days. split from a patch by Chris Wilson
Diffstat (limited to 'src/gallium/drivers/iris/iris_batch.c')
-rw-r--r--src/gallium/drivers/iris/iris_batch.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/gallium/drivers/iris/iris_batch.c b/src/gallium/drivers/iris/iris_batch.c
index bae1720601e..94c66409e1a 100644
--- a/src/gallium/drivers/iris/iris_batch.c
+++ b/src/gallium/drivers/iris/iris_batch.c
@@ -144,16 +144,16 @@ iris_init_batch(struct iris_batch *batch,
struct iris_screen *screen,
struct iris_vtable *vtbl,
struct pipe_debug_callback *dbg,
- uint8_t ring)
+ uint8_t engine)
{
batch->screen = screen;
batch->vtbl = vtbl;
batch->dbg = dbg;
- /* ring should be one of I915_EXEC_RENDER, I915_EXEC_BLT, etc. */
- assert((ring & ~I915_EXEC_RING_MASK) == 0);
- assert(util_bitcount(ring) == 1);
- batch->ring = ring;
+ /* engine should be one of I915_EXEC_RENDER, I915_EXEC_BLT, etc. */
+ assert((engine & ~I915_EXEC_RING_MASK) == 0);
+ assert(util_bitcount(engine) == 1);
+ batch->engine = engine;
batch->exec_count = 0;
batch->exec_array_size = 100;
@@ -419,7 +419,7 @@ submit_batch(struct iris_batch *batch, int in_fence_fd, int *out_fence_fd)
.buffer_count = batch->exec_count,
.batch_start_offset = 0,
.batch_len = batch->primary_batch_size,
- .flags = batch->ring |
+ .flags = batch->engine |
I915_EXEC_NO_RELOC |
I915_EXEC_BATCH_FIRST |
I915_EXEC_HANDLE_LUT,